@@ -16,7 +16,7 @@ EV, Event, Coro::EV, Coro::Event, Glib, Tk, Perl - various supported event loops
       ...
    });
 
-   my $w = AnyEvent->condvar; # stores wether a condition was flagged
+   my $w = AnyEvent->condvar; # stores whether a condition was flagged
    $w->wait; # enters "main loop" till $condvar gets ->broadcast
    $w->broadcast; # wake up current and all future wait's
 
@@ -31,8 +31,9 @@ policy> and AnyEvent is I<small and efficient>.
 First and foremost, I<AnyEvent is not an event model> itself, it only
 interfaces to whatever event model the main program happens to use in a
 pragmatic way. For event models and certain classes of immortals alike,
-the statement "there can only be one" is a bitter reality, and AnyEvent
-helps hiding the differences.
+the statement "there can only be one" is a bitter reality: In general,
+only one event loop can be active at the same time in a process. AnyEvent
+helps hiding the differences between those event loops.
 
 The goal of AnyEvent is to offer module authors the ability to do event
 programming (waiting for I/O or timer events) without subscribing to a
@@ -40,24 +41,27 @@ religion, a way of living, and most importantly: without forcing your
 module users into the same thing by forcing them to use the same event
 model you use.
 
-For modules like POE or IO::Async (which is actually doing all I/O
-I<synchronously>...), using them in your module is like joining a
-cult: After you joined, you are dependent on them and you cannot use
-anything else, as it is simply incompatible to everything that isn't
-itself.
+For modules like POE or IO::Async (which is a total misnomer as it is
+actually doing all I/O I<synchronously>...), using them in your module is
+like joining a cult: After you joined, you are dependent on them and you
+cannot use anything else, as it is simply incompatible to everything that
+isn't itself. What's worse, all the potential users of your module are
+I<also> forced to use the same event loop you use.
 
-AnyEvent + POE works fine. AnyEvent + Glib works fine. AnyEvent + Tk
-works fine etc. etc. but none of these work together with the rest: POE
-+ IO::Async? no go. Tk + Event? no go. If your module uses one of
-those, every user of your module has to use it, too. If your module
-uses AnyEvent, it works transparently with all event models it supports
-(including stuff like POE and IO::Async).
+AnyEvent is different: AnyEvent + POE works fine. AnyEvent + Glib works
+fine. AnyEvent + Tk works fine etc. etc. but none of these work together
+with the rest: POE + IO::Async? no go. Tk + Event? no go. Again: if
+your module uses one of those, every user of your module has to use it,
+too. But if your module uses AnyEvent, it works transparently with all
+event models it supports (including stuff like POE and IO::Async, as long
+as those use one of the supported event loops. It is trivial to add new
+event loops to AnyEvent, too, so it is future-proof).
 
-In addition of being free of having to use I<the one and only true event
+In addition to being free of having to use I<the one and only true event
 model>, AnyEvent also is free of bloat and policy: with POE or similar
-modules, you get an enourmous amount of code and strict rules you have
-to follow. AnyEvent, on the other hand, is lean and to the point by only
-offering the functionality that is useful, in as thin as a wrapper as
+modules, you get an enourmous amount of code and strict rules you have to
+follow. AnyEvent, on the other hand, is lean and up to the point, by only
+offering the functionality that is necessary, in as thin as a wrapper as
 technically possible.
 
 Of course, if you want lots of policy (this can arguably be somewhat
@@ -72,19 +76,20 @@ allows module authors to utilise an event loop without forcing module
 users to use the same event loop (as only a single event loop can coexist
 peacefully at any one time).
 
-The interface itself is vaguely similar but not identical to the Event
+The interface itself is vaguely similar, but not identical to the L<Event>
 module.
 
-On the first call of any method, the module tries to detect the currently
-loaded event loop by probing wether any of the following modules is
-loaded: L<Coro::EV>, L<Coro::Event>, L<EV>, L<Event>, L<Glib>, L<Tk>. The
-first one found is used. If none are found, the module tries to load these
-modules in the order given. The first one that could be successfully
-loaded will be used. If still none could be found, AnyEvent will fall back
-to a pure-perl event loop, which is also not very efficient.
+During the first call of any watcher-creation method, the module tries
+to detect the currently loaded event loop by probing whether one of the
+following modules is already loaded: L<Coro::EV>, L<Coro::Event>, L<EV>,
+L<Event>, L<Glib>, L<Tk>. The first one found is used. If none are found,
+the module tries to load these modules in the stated order. The first one
+that can be successfully loaded will be used. If, after this, still none
+could be found, AnyEvent will fall back to a pure-perl event loop, which
+is not very efficient, but should work everywhere.
 
 Because AnyEvent first checks for modules that are already loaded, loading
-an Event model explicitly before first using AnyEvent will likely make
+an event model explicitly before first using AnyEvent will likely make
 that model the default. For example:
 
    use Tk;
@@ -92,6 +97,10 @@ that model the default. For example:
 
    # .. AnyEvent will likely default to Tk
 
+The I<likely> means that, if any module loads another event model and
+starts using it, all bets are off. Maybe you should tell their authors to
+use AnyEvent so their modules work together with others seamlessly...
+
 The pure-perl implementation of AnyEvent is called
 C<AnyEvent::Impl::Perl>. Like other event modules you can load it
 explicitly.
@@ -103,25 +112,50 @@ stores relevant data for each kind of event you are waiting for, such as
 the callback to call, the filehandle to watch, etc.
 
 These watchers are normal Perl objects with normal Perl lifetime. After
-creating a watcher it will immediately "watch" for events and invoke
-the callback. To disable the watcher you have to destroy it (e.g. by
-setting the variable that stores it to C<undef> or otherwise deleting all
-references to it).
+creating a watcher it will immediately "watch" for events and invoke the
+callback when the event occurs (of course, only when the event model
+is in control).
+
+To disable the watcher you have to destroy it (e.g. by setting the
+variable you store it in to C<undef> or otherwise deleting all references
+to it).
 
 All watchers are created by calling a method on the C<AnyEvent> class.
 
+Many watchers either are used with "recursion" (repeating timers for
+example), or need to refer to their watcher object in other ways.
+
+An any way to achieve that is this pattern:
+
+  my $w; $w = AnyEvent->type (arg => value ..., cb => sub {
+     # you can use $w here, for example to undef it
+     undef $w;
+  });
+
+Note that C<my $w; $w => combination. This is necessary because in Perl,
+my variables are only visible after the statement in which they are
+declared.
+
 =head2 IO WATCHERS
 
-You can create I/O watcher by calling the C<< AnyEvent->io >> method with
-the following mandatory arguments:
+You can create an I/O watcher by calling the C<< AnyEvent->io >> method
+with the following mandatory key-value pairs as arguments:
 
-C<fh> the Perl I<filehandle> (not filedescriptor) to watch for
-events. C<poll> must be a string that is either C<r> or C<w>, that creates
-a watcher waiting for "r"eadable or "w"ritable events. C<cb> the callback
-to invoke everytime the filehandle becomes ready.
+C<fh> the Perl I<file handle> (I<not> file descriptor) to watch for
+events. C<poll> must be a string that is either C<r> or C<w>, which
+creates a watcher waiting for "r"eadable or "w"ritable events,
+respectively. C<cb> is the callback to invoke each time the file handle
+becomes ready.
 
-Filehandles will be kept alive, so as long as the watcher exists, the
-filehandle exists, too.
+File handles will be kept alive, so as long as the watcher exists, the
+file handle exists, too.
+
+It is not allowed to close a file handle as long as any watcher is active
+on the underlying file descriptor.
+
+Some event loops issue spurious readyness notifications, so you should
+always use non-blocking calls when reading/writing from/to your file
+handles.
 
 Example:
 
@@ -137,8 +171,9 @@ Example:
 You can create a time watcher by calling the C<< AnyEvent->timer >>
 method with the following mandatory arguments:
 
-C<after> after how many seconds (fractions are supported) should the timer
-activate. C<cb> the callback to invoke.
+C<after> specifies after how many seconds (fractional values are
+supported) should the timer activate. C<cb> the callback to invoke in that
+case.
 
 The timer callback will be invoked at most once: if you want a repeating
 timer you have to create a new watcher (this is a limitation by both Tk
@@ -154,21 +189,104 @@ Example:
    # to cancel the timer:
    undef $w;
 
-=head2 CONDITION WATCHERS
+Example 2:
 
-Condition watchers can be created by calling the C<< AnyEvent->condvar >>
+   # fire an event after 0.5 seconds, then roughly every second
+   my $w;
+
+   my $cb = sub {
+      # cancel the old timer while creating a new one
+      $w = AnyEvent->timer (after => 1, cb => $cb);
+   };
+
+   # start the "loop" by creating the first watcher
+   $w = AnyEvent->timer (after => 0.5, cb => $cb);
+
+=head3 TIMING ISSUES
+
+There are two ways to handle timers: based on real time (relative, "fire
+in 10 seconds") and based on wallclock time (absolute, "fire at 12
+o'clock").
+
+While most event loops expect timers to specified in a relative way, they use
+absolute time internally. This makes a difference when your clock "jumps",
+for example, when ntp decides to set your clock backwards from the wrong 2014-01-01 to
+2008-01-01, a watcher that you created to fire "after" a second might actually take
+six years to finally fire.
+
+AnyEvent cannot compensate for this. The only event loop that is conscious
+about these issues is L<EV>, which offers both relative (ev_timer) and
+absolute (ev_periodic) timers.
+
+AnyEvent always prefers relative timers, if available, matching the
+AnyEvent API.
+
+=head2 SIGNAL WATCHERS
+
+You can watch for signals using a signal watcher, C<signal> is the signal
+I<name> without any C<SIG> prefix, C<cb> is the Perl callback to
+be invoked whenever a signal occurs.
+
+Multiple signals occurances can be clumped together into one callback
+invocation, and callback invocation will be synchronous. synchronous means
+that it might take a while until the signal gets handled by the process,
+but it is guarenteed not to interrupt any other callbacks.
+
+The main advantage of using these watchers is that you can share a signal
+between multiple watchers.
+
+This watcher might use C<%SIG>, so programs overwriting those signals
+directly will likely not work correctly.
+
+Example: exit on SIGINT
+
+   my $w = AnyEvent->signal (signal => "INT", cb => sub { exit 1 });
+
+=head2 CHILD PROCESS WATCHERS
+
+You can also watch on a child process exit and catch its exit status.
+
+The child process is specified by the C<pid> argument (if set to C<0>, it
+watches for any child process exit). The watcher will trigger as often
+as status change for the child are received. This works by installing a
+signal handler for C<SIGCHLD>. The callback will be called with the pid
+and exit status (as returned by waitpid).
+
+Example: wait for pid 1333
+
+  my $w = AnyEvent->child (
+     pid => 1333,
+     cb  => sub {
+        my ($pid, $status) = @_;
+        warn "pid $pid exited with status $status";
+     },
+  );
+
+=head2 CONDITION VARIABLES
+
+Condition variables can be created by calling the C<< AnyEvent->condvar >>
 method without any arguments.
 
-A condition watcher watches for a condition - precisely that the C<<
+A condition variable waits for a condition - precisely that the C<<
 ->broadcast >> method has been called.
 
-Note that condition watchers recurse into the event loop - if you have
-two watchers that call C<< ->wait >> in a round-robbin fashion, you
-lose. Therefore, condition watchers are good to export to your caller, but
-you should avoid making a blocking wait, at least in callbacks, as this
-usually asks for trouble.
+They are very useful to signal that a condition has been fulfilled, for
+example, if you write a module that does asynchronous http requests,
+then a condition variable would be the ideal candidate to signal the
+availability of results.
 
-The watcher has only two methods:
+You can also use condition variables to block your main program until
+an event occurs - for example, you could C<< ->wait >> in your main
+program until the user clicks the Quit button in your app, which would C<<
+->broadcast >> the "quit" event.
+
+Note that condition variables recurse into the event loop - if you have
+two pirces of code that call C<< ->wait >> in a round-robbin fashion, you
+lose. Therefore, condition variables are good to export to your caller, but
+you should avoid making a blocking wait yourself, at least in callbacks,
+as this asks for trouble.
+
+This object has two methods:
 
 =over 4
 
@@ -181,9 +299,9 @@ You can only wait once on a condition - additional calls will return
 immediately.
 
 Not all event models support a blocking wait - some die in that case
-(programs might want to do that so they stay interactive), so I<if you
-are using this from a module, never require a blocking wait>, but let the
-caller decide wether the call will block or not (for example, by coupling
+(programs might want to do that to stay interactive), so I<if you are
+using this from a module, never require a blocking wait>, but let the
+caller decide whether the call will block or not (for example, by coupling
 condition variables with some kind of request results and supporting
 callbacks so the caller knows that getting the result will not block,
 while still suppporting blocking waits if the caller so desires).
@@ -191,15 +309,17 @@ while still suppporting blocking waits if the caller so desires).
 Another reason I<never> to C<< ->wait >> in a module is that you cannot
 sensibly have two C<< ->wait >>'s in parallel, as that would require
 multiple interpreters or coroutines/threads, none of which C<AnyEvent>
-can supply (the coroutine-aware backends C<Coro::EV> and C<Coro::Event>
-explicitly support concurrent C<< ->wait >>'s from different coroutines,
-however).
+can supply (the coroutine-aware backends L<AnyEvent::Impl::CoroEV> and
+L<AnyEvent::Impl::CoroEvent> explicitly support concurrent C<< ->wait >>'s
+from different coroutines, however).
 
 =item $cv->broadcast
 
 Flag the condition as ready - a running C<< ->wait >> and all further
-calls to C<wait> will return after this method has been called. If nobody
-is waiting the broadcast will be remembered..
+calls to C<wait> will (eventually) return after this method has been
+called. If nobody is waiting the broadcast will be remembered..
+
+=back
 
 Example:
 
@@ -209,38 +329,17 @@ Example:
    # do something such as adding a timer
    # or socket watcher the calls $result_ready->broadcast
    # when the "result" is ready.
+   # in this case, we simply use a timer:
+   my $w = AnyEvent->timer (
+      after => 1,
+      cb    => sub { $result_ready->broadcast },
+   );
 
+   # this "blocks" (while handling events) till the watcher
+   # calls broadcast
    $result_ready->wait;
 
-=back
-
-=head2 SIGNAL WATCHERS
-
-You can listen for signals using a signal watcher, C<signal> is the signal
-I<name> without any C<SIG> prefix. Multiple signals events can be clumped
-together into one callback invocation, and callback invocation might or
-might not be asynchronous.
-
-These watchers might use C<%SIG>, so programs overwriting those signals
-directly will likely not work correctly.
-
-Example: exit on SIGINT
-
-   my $w = AnyEvent->signal (signal => "INT", cb => sub { exit 1 });
-
-=head2 CHILD PROCESS WATCHERS
-
-You can also listen for the status of a child process specified by the
-C<pid> argument (or any child if the pid argument is 0). The watcher will
-trigger as often as status change for the child are received. This works
-by installing a signal handler for C<SIGCHLD>. The callback will be called with
-the pid and exit status (as returned by waitpid).
-
-Example: wait for pid 1333
-
-  my $w = AnyEvent->child (pid => 1333, cb => sub { warn "exit status $?" });
-
-=head1 GLOBALS
+=head1 GLOBAL VARIABLES AND FUNCTIONS
 
 =over 4
 
@@ -264,41 +363,53 @@ The known classes so far are:
 
 =item AnyEvent::detect
 
-Returns C<$AnyEvent::MODEL>, forcing autodetection of the event model if
-necessary. You should only call this function right before you would have
-created an AnyEvent watcher anyway, that is, very late at runtime.
+Returns C<$AnyEvent::MODEL>, forcing autodetection of the event model
+if necessary. You should only call this function right before you would
+have created an AnyEvent watcher anyway, that is, as late as possible at
+runtime.
 
 =back
 
 =head1 WHAT TO DO IN A MODULE
 
-As a module author, you should "use AnyEvent" and call AnyEvent methods
+As a module author, you should C<use AnyEvent> and call AnyEvent methods
 freely, but you should not load a specific event module or rely on it.
 
-Be careful when you create watchers in the module body - Anyevent will
+Be careful when you create watchers in the module body - AnyEvent will
 decide which event module to use as soon as the first method is called, so
 by calling AnyEvent in your module body you force the user of your module
 to load the event module first.
 
+Never call C<< ->wait >> on a condition variable unless you I<know> that
+the C<< ->broadcast >> method has been called on it already. This is
+because it will stall the whole program, and the whole point of using
+events is to stay interactive.
+
+It is fine, however, to call C<< ->wait >> when the user of your module
+requests it (i.e. if you create a http request object ad have a method
+called C<results> that returns the results, it should call C<< ->wait >>
+freely, as the user of your module knows what she is doing. always).
+
 =head1 WHAT TO DO IN THE MAIN PROGRAM
 
 There will always be a single main program - the only place that should
 dictate which event model to use.
 
 If it doesn't care, it can just "use AnyEvent" and use it itself, or not
-do anything special and let AnyEvent decide which implementation to chose.
+do anything special (it does not need to be event-based) and let AnyEvent
+decide which implementation to chose if some module relies on it.
 
-If the main program relies on a specific event model (for example, in Gtk2
-programs you have to rely on either Glib or Glib::Event), you should load
-it before loading AnyEvent or any module that uses it, generally, as early
-as possible. The reason is that modules might create watchers when they
-are loaded, and AnyEvent will decide on the event model to use as soon as
-it creates watchers, and it might chose the wrong one unless you load the
-correct one yourself.
+If the main program relies on a specific event model. For example, in
+Gtk2 programs you have to rely on the Glib module. You should load the
+event module before loading AnyEvent or any module that uses it: generally
+speaking, you should load it as early as possible. The reason is that
+modules might create watchers when they are loaded, and AnyEvent will
+decide on the event model to use as soon as it creates watchers, and it
+might chose the wrong one unless you load the correct one yourself.
 
 You can chose to use a rather inefficient pure-perl implementation by
-loading the C<AnyEvent::Impl::Perl> module, but letting AnyEvent chose is
-generally better.
+loading the C<AnyEvent::Impl::Perl> module, which gives you similar
+behaviour everywhere, but letting AnyEvent chose is generally better.
 
 =cut
 
@@ -309,7 +420,7 @@ use strict;
 
 use Carp;
 
-our $VERSION = '3.1';
+our $VERSION = '3.11';
 our $MODEL;
 
 our $AUTOLOAD;
@@ -483,61 +594,74 @@ sub AnyEvent::Base::Child::DESTROY {
 
 =head1 SUPPLYING YOUR OWN EVENT MODEL INTERFACE
 
+This is an advanced topic that you do not normally need to use AnyEvent in
+a module. This section is only of use to event loop authors who want to
+provide AnyEvent compatibility.
+
 If you need to support another event library which isn't directly
 supported by AnyEvent, you can supply your own interface to it by
 pushing, before the first watcher gets created, the package name of
 the event module and the package name of the interface to use onto
 C<@AnyEvent::REGISTRY>. You can do that before and even without loading
-AnyEvent.
+AnyEvent, so it is reasonably cheap.
 
 Example:
 
    push @AnyEvent::REGISTRY, [urxvt => urxvt::anyevent::];
 
 This tells AnyEvent to (literally) use the C<urxvt::anyevent::>
-package/class when it finds the C<urxvt> package/module is loaded. When
-AnyEvent is loaded and asked to find a suitable event model, it will
-first check for the presence of urxvt.
+package/class when it finds the C<urxvt> package/module is already loaded.
 
-The class should provide implementations for all watcher types (see
-L<AnyEvent::Impl::Event> (source code), L<AnyEvent::Impl::Glib>
-(Source code) and so on for actual examples, use C<perldoc -m
-AnyEvent::Impl::Glib> to see the sources).
+When AnyEvent is loaded and asked to find a suitable event model, it
+will first check for the presence of urxvt by trying to C<use> the
+C<urxvt::anyevent> module.
 
-The above isn't fictitious, the I<rxvt-unicode> (a.k.a. urxvt)
-uses the above line as-is. An interface isn't included in AnyEvent
-because it doesn't make sense outside the embedded interpreter inside
-I<rxvt-unicode>, and it is updated and maintained as part of the
+The class should provide implementations for all watcher types. See
+L<AnyEvent::Impl::EV> (source code), L<AnyEvent::Impl::Glib> (Source code)
+and so on for actual examples. Use C<perldoc -m AnyEvent::Impl::Glib> to
+see the sources.
+
+If you don't provide C<signal> and C<child> watchers than AnyEvent will
+provide suitable (hopefully) replacements.
+
+The above example isn't fictitious, the I<rxvt-unicode> (a.k.a. urxvt)
+terminal emulator uses the above line as-is. An interface isn't included
+in AnyEvent because it doesn't make sense outside the embedded interpreter
+inside I<rxvt-unicode>, and it is updated and maintained as part of the
 I<rxvt-unicode> distribution.
 
 I<rxvt-unicode> also cheats a bit by not providing blocking access to
 condition variables: code blocking while waiting for a condition will
 C<die>. This still works with most modules/usages, and blocking calls must
-not be in an interactive application, so it makes sense.
+not be done in an interactive application, so it makes sense.
 
 =head1 ENVIRONMENT VARIABLES
 
 The following environment variables are used by this module:
 
-C<PERL_ANYEVENT_VERBOSE> when set to C<2> or higher, reports which event
-model gets used.
+C<PERL_ANYEVENT_VERBOSE> when set to C<2> or higher, cause AnyEvent to
+report to STDERR which event model it chooses.
 
-=head1 EXAMPLE
+=head1 EXAMPLE PROGRAM
 
-The following program uses an io watcher to read data from stdin, a timer
-to display a message once per second, and a condvar to exit the program
-when the user enters quit:
+The following program uses an IO watcher to read data from STDIN, a timer
+to display a message once per second, and a condition variable to quit the
+program when the user enters quit:
 
    use AnyEvent;
 
    my $cv = AnyEvent->condvar;
 
-   my $io_watcher = AnyEvent->io (fh => \*STDIN, poll => 'r', cb => sub {
-      warn "io event <$_[0]>\n";   # will always output <r>
-      chomp (my $input = <STDIN>); # read a line
-      warn "read: $input\n";       # output what has been read
-      $cv->broadcast if $input =~ /^q/i; # quit program if /^q/i
-   });
+   my $io_watcher = AnyEvent->io (
+      fh   => \*STDIN,
+      poll => 'r',
+      cb   => sub {
+         warn "io event <$_[0]>\n";   # will always output <r>
+         chomp (my $input = <STDIN>); # read a line
+         warn "read: $input\n";       # output what has been read
+         $cv->broadcast if $input =~ /^q/i; # quit program if /^q/i
+      },
+   );
 
    my $time_watcher; # can only be used once
 
@@ -629,7 +753,7 @@ data:
 
 The actual code goes further and collects all errors (C<die>s, exceptions)
 that occured during request processing. The C<result> method detects
-wether an exception as thrown (it is stored inside the $txn object)
+whether an exception as thrown (it is stored inside the $txn object)
 and just throws the exception, which means connection errors and other
 problems get reported tot he code that tries to use the result, not in a
 random callback.
